@@ -34,6 +34,6 @@ Disclaimer: Please do not use for navigation.
 extern int disableapm;
 
 int battery_get_values(void);
-void expose_display_battery();
+int expose_display_battery();
 
 #endif /* GPSDRIVE_BATTERY_H */
