@@ -1,4 +1,4 @@
-// $Id: garmin_serial.h,v 1.1 2001/08/26 23:40:10 ganter Exp $
+// $Id: garmin_serial.h,v 1.2 2003/04/28 15:10:03 ganter Exp $
 // garmin_serial.h
 // Douglas S. J. De Couto
 // September 7, 1998
@@ -20,7 +20,7 @@
 #define _garserh
 
 #include "garmin_phys.h"
-#include <linux/serial.h>
+#include "serial.h"
 
 // adapter class to use serial port object for garmin physical layer
 
