@@ -1402,11 +1402,11 @@ static char * speedtrap_xpm[] = {
 "     {**;;;,,;;;@*)     ",
 "     @@*;;;,,;;;@@@     ",
 "    ]**^;;;,,;;;^**$    ",
-"    @*@;;;;/,;;;;***    ",
-"   #@@^;;;;(,;;;;-@@_   ",
-"   **@;;;;;:<;;;;;***   ",
+"    @*@;;;;,,;;;;***    ",
+"   #@@^;;;;,,;;;;-@@_   ",
+"   **@;;;;;;;;;;;;***   ",
 "  [@@^;;;;;,,:;;;;-**}  ",
-"  ***;;;;;;/,;;;;;;@*@  ",
+"  ***;;;;;;,,;;;;;;@*@  ",
 " @@@;;;;;;;;;;;;;;;;*@* ",
 " @@********@**@*@****** ",
 "@@@@@*******************",
@@ -2018,3 +2018,163 @@ static char * cafe_xpm[] = {
 "    ! #.# v+w+x+ .i y+x+i =+x+ .z+S.A+# # 6     ",
 "          l.3 B+5.C+D+E+>+F+G+|+6 H+6           ",
 "                I+! ! J+4 o+K+! S.]+            "};
+
+
+/* XPM */
+static char * kismet_xpm[] = {
+"36 20 101 2",
+"  	c None",
+". 	c #C7C8EA",
+"+ 	c #C4C5E9",
+"@ 	c #C6C7EA",
+"# 	c #C5C6EA",
+"$ 	c #C3C4E9",
+"% 	c #C8C9EB",
+"& 	c #C9CAEB",
+"* 	c #C4C5EA",
+"= 	c #C7C8EB",
+"- 	c #B8B8E4",
+"; 	c #A1A1DB",
+"> 	c #B8B9E4",
+", 	c #BCBDE6",
+"' 	c #BEBFE7",
+") 	c #BDBEE7",
+"! 	c #413DB3",
+"~ 	c #231FA7",
+"{ 	c #2D2AAB",
+"] 	c #3835B0",
+"^ 	c #4743B6",
+"/ 	c #2A26AA",
+"( 	c #2420A7",
+"_ 	c #2623A9",
+": 	c #8E8ED3",
+"< 	c #B9B9E5",
+"[ 	c #2925AA",
+"} 	c #2420A8",
+"| 	c #7674C9",
+"1 	c #4946B7",
+"2 	c #2320A8",
+"3 	c #4C49B8",
+"4 	c #514EB9",
+"5 	c #504DB9",
+"6 	c #504CB9",
+"7 	c #2825A9",
+"8 	c #4D4AB8",
+"9 	c #322FAD",
+"0 	c #8180CE",
+"a 	c #6361C2",
+"b 	c #2926AA",
+"c 	c #5D5CBF",
+"d 	c #3632AF",
+"e 	c #514DB9",
+"f 	c #231FA8",
+"g 	c #4E4BB9",
+"h 	c #2F2CAC",
+"i 	c #3A37B1",
+"j 	c #413EB3",
+"k 	c #332FAD",
+"l 	c #2521A8",
+"m 	c #4643B5",
+"n 	c #4A47B7",
+"o 	c #9E9EDA",
+"p 	c #B9BAE5",
+"q 	c #2824A9",
+"r 	c #3F3CB3",
+"s 	c #2C28AB",
+"t 	c #6966C3",
+"u 	c #4946B6",
+"v 	c #413EB4",
+"w 	c #2D29AB",
+"x 	c #5856BD",
+"y 	c #2C29AB",
+"z 	c #9B9BD9",
+"A 	c #3D3AB2",
+"B 	c #322EAD",
+"C 	c #3834B0",
+"D 	c #4D49B8",
+"E 	c #514EBA",
+"F 	c #3B38B1",
+"G 	c #7876CA",
+"H 	c #6D6CC6",
+"I 	c #5250BB",
+"J 	c #524FBB",
+"K 	c #2622A8",
+"L 	c #4C48B7",
+"M 	c #3C39B1",
+"N 	c #4542B5",
+"O 	c #4945B6",
+"P 	c #4743B5",
+"Q 	c #4E4BB8",
+"R 	c #8685D0",
+"S 	c #4340B4",
+"T 	c #5D5BBF",
+"U 	c #6765C3",
+"V 	c #5552BB",
+"W 	c #4F4CB9",
+"X 	c #312DAD",
+"Y 	c #4D4BB8",
+"Z 	c #2B27AB",
+"` 	c #615FC1",
+" .	c #4643B6",
+"..	c #716FC7",
+"+.	c #BABBE5",
+"@.	c #A9A9DE",
+"#.	c #B3B3E2",
+"$.	c #BABAE5",
+"%.	c #B8B9E5",
+"&.	c #B7B8E4",
+"*.	c #C9C9EB",
+"                            . . + + @ @                                 ",
+"                        # $ $ $ $ $ $ $ $ +                             ",
+"                    % $ $ $ # . . . @ $ $ $ $ &                         ",
+"                    + $ * = # $ $ $ + . # $ $ @                         ",
+"                      # @ $ $ $ $ $ $ $ # @ *                           ",
+"                      % $ $ $ + . # $ $ $ @                             ",
+"                        - ; > @ $ + , > ' )                             ",
+"! ~   { ]     ^ ~       / ( _ : $ < [ } | 1 2 3     4 ~ ~ 5   6 ~ ~ ~ 7 ",
+"! ~ 1 ~ 8     ^ ~     9 } 0 } a $ < b } c d ~ 8     e f g       h ~ i   ",
+"j } k l       ^ ~     m 2 n o p $ < [ q r s q 8     5 ~ t         ~ u   ",
+"v ~ ~ w       ^ ~       x ( y z = p [ A l B C D     E ~ ~         2 1   ",
+"! ~ F ~       ^ ~       G H } I   p [ J K L M 8     E ~           ~ 1   ",
+"j ~ N ~ O     P ~     Q ~ R [ S     b T B U M 8     5 ~ V         ~ 1   ",
+"! ~ W q X     m ~       h l l Y     Z `  ...i 3     E ~ ~ ~       ~ u   ",
+"                      # +.o @.      #.$.%., &.                          ",
+"                      $ $ $           + $ $ *                           ",
+"                    + $ $ %           *.$ $ $ @                         ",
+"                    % $ $ #           @ $ $ $ &                         ",
+"                        # $ $ # % . # $ $ +                             ",
+"                            . . + + @ @                                 "};
+
+/* XPM */
+static char *geocache_xpm[]={
+"24 24 6 1",
+"  c None",
+"a c #00c000",
+"b c #303030",
+"c c #58a8ff",
+". c #c0c000",
+"d c #ff0000",
+"...........  aaaaaaaaaaa",
+"..........bbbbaaaaaaaaaa",
+"........bb.  abbaaaaaaaa",
+"......bb...  aaabbaaaaaa",
+"......bb...  aaabbaaaaaa",
+"......b.bb.  abbabaaaaaa",
+"......b...bbbbaaabaaaaaa",
+"......b....  aaaabaaaaaa",
+"......b....  aaaabaaaaaa",
+"......b....  aaaabaaaaaa",
+"......b....  aaaabaaaaaa",
+"      b          b      ",
+"      b          b      ",
+"ccccccbcccc  ddddbdddddd",
+"ccccccbcccc  ddddbdddddd",
+"ccccccbcccc  ddddbdddddd",
+"ccccccbcccc  ddddbdddddd",
+"ccccccbcccc  ddddbdddddd",
+"ccccccbcccc  ddddbdddddd",
+"ccccccbbccc  dddbbdddddd",
+"ccccccccbbc  dbbdddddddd",
+"ccccccccccbbbbdddddddddd",
+"ccccccccccc  ddddddddddd",
+"ccccccccccc  ddddddddddd"};
