@@ -1221,3 +1221,197 @@ static char * powercord_xpm[] = {
 "            /$($_$:$d@<$          ",
 "            [$v#I#}$|$            "};
 
+/* XPM */
+static char * gauge_xpm[] = {
+"19 50 3 1",
+" 	c none",
+".	c #000000000000",
+"X	c #FFFF00000000",
+"     ..........    ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX..      ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX....    ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX..      ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX....    ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX..      ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX....    ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX..      ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX.       ",
+"     .XXXXX..      ",
+"    .XXXXXXXX.     ",
+"   .XXXXXXXXXX.    ",
+"   .XXXXXXXXXX.    ",
+"   .XXXXXXXXXX.    ",
+"   .XXXXXXXXXX.    ",
+"   .XXXXXXXXXX.    ",
+"    .XXXXXXXX.     ",
+"     ..XXXX..      ",
+"       ....        "};
+
+
+/* XPM */
+static char * powercharges_xpm[] = {
+"17 50 83 1",
+" 	c none",
+".	c #90909898A0A0",
+"X	c #909090909898",
+"o	c #90909090A0A0",
+"O	c #A0A0A0A0A8A8",
+"+	c #9898A0A0A8A8",
+"@	c #808088889090",
+"#	c #808080808888",
+"$	c #686868687878",
+"%	c #787878788888",
+"&	c #A8A8A8A8B0B0",
+"*	c #707070707878",
+"=	c #505058586060",
+"-	c #303038383838",
+";	c #282830303838",
+":	c #383840404848",
+">	c #303030303838",
+",	c #383838384040",
+"<	c #383840404040",
+"1	c #404048484848",
+"2	c #303038384040",
+"3	c #484848485050",
+"4	c #808080809090",
+"5	c #101018181818",
+"6	c #000008080808",
+"7	c #181820202020",
+"8	c #484850505858",
+"9	c #505058585858",
+"0	c #080810101010",
+"q	c #080808081010",
+"w	c #686868687070",
+"e	c #505050505858",
+"r	c #282830303030",
+"t	c #404040404848",
+"y	c #FFFFFFFF0000",
+"u	c #282828283030",
+"i	c #484850505050",
+"p	c #585860606868",
+"a	c #404040404040",
+"s	c #585858585858",
+"d	c #585860606060",
+"f	c #585858586060",
+"g	c #484848484848",
+"h	c #303030303030",
+"j	c #202028282828",
+"k	c #404048485050",
+"l	c #202020202020",
+"z	c #202020202828",
+"x	c #181818182020",
+"c	c #383838383838",
+"v	c #808088888888",
+"b	c #181818181818",
+"n	c #101010101010",
+"m	c #080808080808",
+"M	c #101010101818",
+"N	c #282828282828",
+"B	c #404040405050",
+"V	c #888888889090",
+"C	c #505050506060",
+"Z	c #888890909090",
+"A	c #909098989898",
+"S	c #202018182020",
+"D	c #B8B8B8B8C8C8",
+"F	c #606060606060",
+"G	c #C8C8C8C8C8C8",
+"H	c #98989898A0A0",
+"J	c #808080808080",
+"K	c #686868686868",
+"L	c #383838384848",
+"P	c #888888888888",
+"I	c #303038383030",
+"U	c #707070707070",
+"Y	c #606060606868",
+"T	c #C0C0C0C0C0C0",
+"R	c #A8A8A8A8A8A8",
+"E	c #505050505050",
+"W	c #C0C0C8C8C8C8",
+"Q	c #D0D0D0D0D0D0",
+"!	c #787878788080",
+"~	c #F0F0F0F0F0F0",
+"^	c #E0E0E8E8E8E8",
+"/	c #E8E8E8E8F0F0",
+"(	c #F8F8F8F8F8F8",
+"                 ",
+"                 ",
+"   ..XoO+.@##$%& ",
+" *=-;;:>,<-12->34",
+" 3:56781:<:9-0q2w",
+" 8er7>=t7yr9-ruip",
+" <asde330yuerifg1",
+" hjh,tk<uy>t<3-l,",
+" <l7zu2,y,,,,ux71",
+" cz77u,<y,t<,jx71",
+" <z77u,y<<yyyux71",
+" 1l5xu2y,y,y-j77<",
+" ilxxuyyy<<y-zx7t",
+" 9lxxu,<<<yt2zx7<",
+"vgl75u,<<<yt2z77-",
+"d-b7xu,<<y<t2zxx>",
+"*cn5xu,<<y<1,zbn>",
+"vtqn5j::<y<1,znm>",
+"#,Mn5u2:::::,j55N",
+"v-zckk:ttBk3kk1uz",
+"Vczc38==eeC==k3rx",
+"Zcz<e88===fff31hl",
+"Xc7,ee8888ee831ul",
+"A<xce======e811NS",
+"Dtx>,h->>>>>>>urx",
+" >lu>huNjjNNNN>N7",
+" Fbu>rNuNNNNNurN3",
+" G-urz>NuuuNz7,NH",
+"  J7>zNNuuuuN>>w ",
+"  flx-uuuuuhh>zK ",
+"  -jbjL:L2,,,5hP ",
+"  <I-j,:8888:NNU ",
+"  al-j>ttttt9ixY ",
+"  *-b5zzzjjxjzlJ ",
+"   9grc>t<c><f#T ",
+"    Rlz7<tu5i    ",
+"    Tnb5c,lbE    ",
+"    W5b0brxxe    ",
+"    Gbbl><zMf    ",
+"    WMbNr5nqK    ",
+"    Qxn7-hxn*    ",
+"     cb5xhMzF    ",
+"      3z3<l!     ",
+"     ~Vzt-I^     ",
+"      Yx,hh/     ",
+"      ,u,Nc      ",
+"      -z,Nh      ",
+"      Vu>NN(     ",
+"      azhuu(     ",
+"      gzhuN      "};
