@@ -21,6 +21,12 @@ Disclaimer: Please do not use for navigation.
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 *********************************************************************/
+/*
+$Log: track.h,v $
+Revision 1.3  2003/05/31 20:12:35  ganter
+new UDP friendsserver build in, needs some work
+
+*/
 
 
 #ifndef GPSDRIVE_TRACK_H
@@ -33,12 +39,6 @@ Disclaimer: Please do not use for navigation.
 #include <gtk/gtk.h>
 
 
-typedef struct
-{
-  gint16 x;
-  gint16 y;
-}
-trackstruct;
 
 typedef struct
 {
